import { Identity, Store } from 'graphql-rate-limit';
export declare type DynamoStoreProps = {
    tableName: string;
    /** Partition key field name. Example: "pk". */
    pk: string;
    /**
     * The sk isn't used, but since dynamo may need it, you can pass an sk with any value here.
     * Example: `{ sk: "sk", value: "-" }` or `{ sk: "sk", value: 0 }`.
     * `sk` will then have value `-` (or `0`) for every row.
     */
    sk?: {
        sk: string;
        value: any;
    };
    /**
     * Pass the name of the ttlField here, if you have it. Otherwise all
     * the rows will hang around forever. The value of the ttl field will be a
     * number. Example: "ttl".
     */
    ttlField?: string;
};
declare abstract class BaseDynamoStore implements Store {
    private readonly nameSpacedKeyPrefix;
    private _tableName;
    private pk;
    private sk?;
    private _ttlField;
    constructor(opts: DynamoStoreProps);
    protected abstract update({}: {
        Key: any;
        UpdateExpression: string;
        ExpressionAttributeNames: any;
        ExpressionAttributeValues: any;
        TableName: string;
    }): Promise<any>;
    protected abstract get({}: {
        Key: any;
        TableName: string;
    }): Promise<{
        Item?: {
            timestamps: readonly number[];
        };
    }>;
    setForIdentity(identity: Identity, timestamps: readonly number[], windowMs?: number): Promise<void>;
    private getTtl;
    getForIdentity(identity: Identity): Promise<readonly number[]>;
    private secs;
    private readonly generateNamedSpacedKey;
}
export { BaseDynamoStore };
